==> all-contributors-2.16.0.tgz: package/docs/overview.md <==
---
id: overview
title: Overview
sidebar_label: Overview
---

> Call for translators! [We're looking for translators](https://github.com/all-contributors/all-contributors/issues/143) to help translate this spec for everyone!

<div align="center">
    <img src="../assets/logo-full-transparent.png" alt="✨ All Contributors ✨" width="800px" />
</div>

<a class="github-button" href="https://github.com/all-contributors/all-contributors" data-icon="octicon-star" data-count-href="/all-contributors/all-contributors/stargazers" data-show-count="true" data-count-aria-label="# stargazers on GitHub" aria-label="Star this project on GitHub" >Star</a>

This is a specification for recognizing contributors to an open source project in a way that rewards each and every contribution, not just code.

The basic idea is this:

> Use the project README (or another prominent public documentation page in the project) to recognize the contributions of members of the project community.

People are giving themselves and their free time to contribute to open source projects in so many ways, so we believe everyone should be praised for their contributions (code or not).

## The All Contributors Table
Below is an example of how using the all-contributors spec table can recognize all contributors
<div align="center">
    <img src="../assets/contributors-table-small.png" alt="All Contributors Table Screenshot" width="800px" />
</div>

> You can use [the @all-contributors bot 🤖](bot/overview) to automate acknowledging contributors to your open source projects

## What's next
- [The all contributors specification](specification)
- [Emoji Key (Contribution Types Reference)](emoji-key)
- [Notes for repository maintainers](repository-maintainers)
- [Automating the process using tools](tooling)

==> all-contributors-2.17.1.tgz: package/docs/overview.md <==
---
id: overview
title: Overview
sidebar_label: Overview
---

> Call for translators! [We're looking for translators](https://github.com/all-contributors/all-contributors/issues/143) to help translate this spec for everyone!

<div align="center">
    <img src="../assets/logo-full-transparent.png" alt="✨ All Contributors ✨" width="800px" />
</div>

<a class="github-button" href="https://github.com/all-contributors/all-contributors" data-icon="octicon-star" data-count-href="/all-contributors/all-contributors/stargazers" data-show-count="true" data-count-aria-label="# stargazers on GitHub" aria-label="Star this project on GitHub" >Star</a>

This is a specification for recognizing contributors to an open-source project in a way that rewards every contribution, not just code.

The basic idea is this:

> Use the project README (or another prominent public documentation page in the project) to recognize the contributions of members of the project community.

People are giving themselves and their free time to contribute to open source projects in so many ways, so we believe everyone should be praised for their contributions (code or not).

## The All Contributors Table

Below is an example of how using the all-contributors spec table can recognize all contributors
<div align="center">
    <img src="../assets/contributors-table-small.png" alt="All Contributors Table Screenshot" width="800px" />
</div>

> You can use [the @all-contributors bot 🤖](bot/overview) to automate acknowledging contributors to your open source projects

## What's next

- [The all contributors specification](specification)
- [Emoji Key (Contribution Types Reference)](emoji-key)
- [Notes for repository maintainers](repository-maintainers)
- [Automating the process using tools](tooling)
